@@ -14,17 +14,10 @@ typedef int Py_ssize_t;
 #include "rsamodule.hpp"
 
 /* from Crypto++ */
-#ifdef USE_NAME_CRYPTO_PLUS_PLUS
-#include <crypto++/filters.h>
-#include <crypto++/osrng.h>
-#include <crypto++/pssr.h>
-#include <crypto++/rsa.h>
-#else
 #include <cryptopp/filters.h>
 #include <cryptopp/osrng.h>
 #include <cryptopp/pssr.h>
 #include <cryptopp/rsa.h>
-#endif
 
 USING_NAMESPACE(CryptoPP)
 
